@@ -8,7 +8,7 @@ from aleksis.core.util.core_helpers import queryset_rules_filter
 
 
 class OrderFilter(django_filters.FilterSet):
-    # full_name = django_filters.CharFilter(lookup_expr='icontains')
+    full_name = django_filters.CharFilter(lookup_expr='icontains')
     items_count = django_filters.NumericRangeFilter(method="items_count_filter")
 
     def items_count_filter(self, queryset, name, value):
