@@ -5,7 +5,7 @@ MENUS = {
         {
             "name": _("Orders"),
             "url": "#",
-            "icon": "shopping_cart",
+            "svg_icon": "mdi:cart-outline",
             "root": True,
             "validators": [
                 ("aleksis.core.util.predicates.permission_validator", "order.show_menu",),
@@ -14,7 +14,7 @@ MENUS = {
                 {
                     "name": _("List"),
                     "url": "list_orders",
-                    "icon": "receipt_long",
+                    "svg_icon": "mdi:receipt-outline",
                     "validators": [
                         ("aleksis.core.util.predicates.permission_validator", "order.view_orders",),
                     ],
