@@ -5,7 +5,7 @@ from blabel import LabelWriter
 from .settings import BASE_DIR
 
 
-def generate_order_labels(orders):
+def generate_order_labels(orders, temp_dir):
     records = []
     for order in orders:
         record = {
@@ -19,10 +19,10 @@ def generate_order_labels(orders):
         os.path.join(BASE_DIR, "order_label.html"),
         default_stylesheets=(os.path.join(BASE_DIR, "order_label_style.css"),),
     )
-    label_writer.write_labels(records, target=os.path.join(BASE_DIR, "labels.pdf"))
+    label_writer.write_labels(records, target=os.path.join(temp_dir, "labels.pdf"))
+    return os.path.join(temp_dir, "labels.pdf")
 
-
-def generate_address_labels(orders):
+def generate_address_labels(orders, temp_dir):
     records = []
     for order in orders:
         record = {
@@ -39,4 +39,5 @@ def generate_address_labels(orders):
         os.path.join(BASE_DIR, "address_label.html"),
         default_stylesheets=(os.path.join(BASE_DIR, "address_label_style.css"),),
     )
-    label_writer.write_labels(records, target=os.path.join(BASE_DIR, "labels.pdf"))
+    label_writer.write_labels(records, target=os.path.join(temp_dir, "labels.pdf"))
+    return os.path.join(temp_dir, "labels.pdf")
\ No newline at end of file
